@@ -73,6 +73,23 @@ COMMON_OPTIONS = {
         ),
     ],
 
+    'save': [
+        click.option(
+            '--save-raw', '-r',
+            is_flag=True,
+            default=False,
+            show_default=True,
+            help='Save adata to adata.raw before processing.',
+        ),
+        click.option(
+            '--save-layer', '-y',
+            type=click.STRING,
+            default=None,
+            show_default=True,
+            help='Save adata.X to the specified layer before processing.',
+        ),
+    ],
+
     'plot': [
         click.argument(
             'output_fig',
@@ -177,7 +194,14 @@ COMMON_OPTIONS = {
         ),
     ],
 
-    
+    'neighbor_metric': click.option(
+        '--metric', '-t',
+        type=click.Choice(['cityblock', 'cosine', 'euclidean', 'l1', 'l2', 'manhattan', 'braycurtis', 'canberra', 'chebyshev', 'correlation', 'dice', 'hamming', 'jaccard', 'kulsinski', 'mahalanobis', 'minkowski', 'rogerstanimoto', 'russellrao', 'seuclidean', 'sokalmichener', 'sokalsneath', 'sqeuclidean', 'yule']),
+        default='euclidean',
+        show_default=True,
+        help='A known metric’s name.'
+    ),
+
     'layer':click.option(
         '--layer',
         type=CommaSeparatedText(simplify=True),
@@ -215,7 +239,7 @@ COMMON_OPTIONS = {
 
     'use_raw': click.option(
         '--use-raw/--no-raw', 'use_raw',
-        default=True,
+        default=None,
         show_default=True,
         help='Use expression values in `.raw` if present.',
     ),
@@ -520,6 +544,28 @@ COMMON_OPTIONS = {
         show_default=True,
         help="Layer to batch correct. By default corrects the contents of .X."
     ),
+
+    'scrublet': [
+        click.option(
+            '--sim-doublet-ratio',
+            type=click.FLOAT,
+            default=2.0,
+            show_default=True,
+            help='Number of doublets to simulate relative to the number of '
+            'observed transcriptomes.',
+        ),
+        click.option(
+            '--synthetic-doublet-umi-subsampling',
+            type=click.FLOAT,
+            default=1.0,
+            show_default=True,
+            help='Where input_obj_sim not suplied, rate for sampling UMIs when '
+            'creating synthetic doublets. If 1.0, each doublet is created by '
+            'simply adding the UMI counts from two randomly sampled observed '
+            'transcriptomes.  For values less than 1, the UMI counts are added '
+            'and then randomly sampled at the specified rate.'
+        ),
+    ],
 }
 
 COMMON_OPTIONS['opt_output'] = [
@@ -584,6 +630,7 @@ CMD_OPTIONS = {
     'filter': [
         *COMMON_OPTIONS['input'],
         *COMMON_OPTIONS['output'],
+        COMMON_OPTIONS['save'][0], # --save-raw
         click.option(
             '--gene-name', '-g',
             type=click.STRING,
@@ -637,14 +684,8 @@ CMD_OPTIONS = {
     'norm': [
         *COMMON_OPTIONS['input'],
         *COMMON_OPTIONS['output'],
+        *COMMON_OPTIONS['save'],
         COMMON_OPTIONS['key_added'],
-        click.option(
-            '--save-raw', '-r',
-            type=click.Choice(['yes', 'no', 'counts']),
-            default='yes',
-            show_default=True,
-            help='Save raw data existing raw data.',
-        ),
         click.option(
             '--no-log-transform', 'log_transform',
             is_flag=True,
@@ -775,6 +816,7 @@ CMD_OPTIONS = {
     'scale': [
         *COMMON_OPTIONS['input'],
         *COMMON_OPTIONS['output'],
+        *COMMON_OPTIONS['save'],
         COMMON_OPTIONS['zero_center'],
         click.option(
             '--max-value', '-m',
@@ -795,6 +837,7 @@ CMD_OPTIONS = {
     'regress': [
         *COMMON_OPTIONS['input'],
         *COMMON_OPTIONS['output'],
+        *COMMON_OPTIONS['save'],
         COMMON_OPTIONS['n_jobs'],
         click.option(
             '--keys', '-k',
@@ -885,13 +928,7 @@ CMD_OPTIONS = {
             'connectivities. Use rapids for the RAPIDS implementation of UMAP '
             '(experimental, GPU only).'
         ),
-        click.option(
-            '--metric', '-t',
-            type=click.Choice(['cityblock', 'cosine', 'euclidean', 'l1', 'l2', 'manhattan', 'braycurtis', 'canberra', 'chebyshev', 'correlation', 'dice', 'hamming', 'jaccard', 'kulsinski', 'mahalanobis', 'minkowski', 'rogerstanimoto', 'russellrao', 'seuclidean', 'sokalmichener', 'sokalsneath', 'sqeuclidean', 'yule']),
-            default='euclidean',
-            show_default=True,
-            help='A known metric’s name.'
-        ),
+        COMMON_OPTIONS['neighbor_metric'],
     ],
 
     'umap': [
@@ -1459,6 +1496,7 @@ CMD_OPTIONS = {
     'mnn': [
         *COMMON_OPTIONS['input'],
         *COMMON_OPTIONS['output'],
+        *COMMON_OPTIONS['save'],
         COMMON_OPTIONS['batch_key'],
         COMMON_OPTIONS['batch_layer'],
         click.option(
@@ -1570,13 +1608,7 @@ CMD_OPTIONS = {
             'potentially increasing the degree of batch correction. Use this flag to disable '
             'that behaviour.',
         ),
-        click.option(
-            '--metric', '-t',
-            type=click.Choice(['angular', 'cityblock', 'cosine', 'euclidean', 'l1', 'l2', 'manhattan', 'braycurtis', 'canberra', 'chebyshev', 'correlation', 'dice', 'hamming', 'jaccard', 'kulsinski', 'mahalanobis', 'minkowski', 'rogerstanimoto', 'russellrao', 'seuclidean', 'sokalmichener', 'sokalsneath', 'sqeuclidean', 'yule']),
-            default='angular',
-            show_default=True,
-            help='A known metric’s name.'
-        ),
+        COMMON_OPTIONS['neighbor_metric'],
         click.option(
             '--neighbors-within-batch',
             type=click.INT,
@@ -1598,7 +1630,7 @@ CMD_OPTIONS = {
             'each cell. Set to 0 to skip.'
         ),
         click.option(
-            '--n-trees',
+            '--annoy-n-trees',
             type=click.INT,
             default=10,
             show_default=True,
@@ -1635,6 +1667,178 @@ CMD_OPTIONS = {
             'connectivity value of 1)'
         ),
     ],
+    
+    'scrublet': [
+        *COMMON_OPTIONS['input'],
+        *COMMON_OPTIONS['output'],
+        click.option(
+            '--batch-key', 'batch_key',
+            type=click.STRING,
+            default=None,
+            help='The name of the column in adata.obs that differentiates among '
+            'experiments/batches. Doublets will be detected in each batch separately.'
+        ),
+        click.option(
+            '--input-obj-sim', 'adata_sim',
+            type=click.Path(exists=True, dir_okay=False),
+            default=None,
+            help='(Advanced use case) Optional annData object generated by '
+            'sc.external.pp.scrublet_simulate_doublets(), with same number of  '
+            'vars as adata. This should have been built from input_obj after '
+            'filtering genes and cells and selcting highly-variable genes.'
+        ),
+        click.option(
+            '--threshold',
+            type=click.FLOAT,
+            default=None,
+            show_default=True,
+            help='Doublet score threshold for calling a transcriptome a '
+            'doublet. If not set, this is set automatically by looking for the '
+            'minimum between the two modes of the doublet_scores_sim_ histogram. '
+            'It is best practice to check the threshold visually using the '
+            'doublet_scores_sim_ histogram and/or based on co-localization of '
+            'predicted doublets in a 2-D embedding.'
+        ),
+        *COMMON_OPTIONS['scrublet'],
+        click.option(
+            '--expected-doublet-rate',
+            type=click.FLOAT,
+            default=0.05,
+            show_default=True,
+            help='Where input_obj_sim not suplied, the estimated doublet rate '
+            'for the experiment.'
+        ),
+        click.option(
+            '--stdev-doublet-rate',
+            type=click.FLOAT,
+            default=0.02,
+            show_default=True,
+            help='Where input_obje_sim not suplied, uncertainty in the expected '
+            'doublet rate.'
+        ),
+         click.option(
+            '--knn-dist-metric', '-t',
+            type=click.Choice(['cityblock', 'cosine', 'euclidean', 'l1', 'l2', 'manhattan', 'braycurtis', 'canberra', 'chebyshev', 'correlation', 'dice', 'hamming', 'jaccard', 'kulsinski', 'mahalanobis', 'minkowski', 'rogerstanimoto', 'russellrao', 'seuclidean', 'sokalmichener', 'sokalsneath', 'sqeuclidean', 'yule']),
+            default='euclidean',
+            show_default=True,
+            help='A known metric’s name.'
+        ),
+        click.option(
+            '--no-normalize-variance', 'normalize_variance',
+            is_flag=True,
+            default=True,
+            help='Default is to normalize the data such that each gene has a '
+            'variance of 1. sklearn.decomposition.TruncatedSVD will be used for '
+            'dimensionality reduction, if --no-mean-center is set. Use this flag '
+            'to disable that behaviour.'
+        ),
+        click.option(
+            '--log-transform',
+            is_flag=True,
+            default=False,
+            show_default=True,
+            help='Whether to use :func:~scanpy.pp.log1p to log-transform the '
+            'data prior to PCA.'
+        ),
+        click.option(
+            '--no-mean-center', 'mean_center',
+            is_flag=True,
+            default=True,
+            help='If True, center the data such that each gene has a mean of 0. '
+            'sklearn.decomposition.PCA will be used for dimensionality '
+            'reduction.'
+        ),
+        click.option(
+            '--n-pcs', 'n_prin_comps',
+            type=click.INT,
+            default=30,
+            show_default=True,
+            help='Number of principal components used to embed the '
+            'transcriptomes prior to k-nearest-neighbor graph construction.'
+        ),
+        click.option(
+            '--no-approx', 'use_approx_neighbors',
+            is_flag=True,
+            default=True,
+            help='Default behaviour is to use the approximate nearest neighbor '
+            'method (annoy) for the KNN classifier. Use this flag to disable '
+            'that behaviour.'
+        ),
+        click.option(
+            '--get-doublet-neighbor-parents',
+            is_flag=True,
+            default=False,
+            show_default=True,
+            help='If set, return (in .uns) the parent transcriptomes that '
+            'generated the doublet neighbors of each observed transcriptome. '
+            'This information can be used to infer the cell states that '
+            'generated a given doublet state.'
+        ),
+        click.option(
+            '--n-neighbors', '-k',
+            type=CommaSeparatedText(click.INT, simplify=True),
+            default=None,
+            show_default=True,
+            help='Number of neighbors used to construct the KNN graph of '
+            'observed transcriptomes and simulated doublets. If not set, this is '
+            'automatically set to np.round(0.5 * np.sqrt(n_obs)).'
+        ),
+        click.option(
+            '--filter', 'filter',
+            is_flag=True,
+            default=False,
+            help='By default, the output object is annotated but not filtered '
+            'according to the scrublet status. Setting this flag will cause '
+            'predicted multiplet elements to be removed.'
+        ),
+        click.option(
+            '--no-verbose', 'verbose',
+            is_flag=True,
+            default=True,
+            help='Default behaviour is to print progress updates. Use this flag '
+            'to disable that.'
+        ),
+        click.option(
+            '--export-table',
+            type=click.Path(dir_okay=False, writable=True),
+            default=None,
+            show_default=True,
+            help='Export a table of double scores and calls to the specified file.',
+        ),
+        COMMON_OPTIONS['random_state'],
+    ],
+    
+    'plot_scrublet': [
+        *COMMON_OPTIONS['input'],
+        *COMMON_OPTIONS['plot'],
+         click.option(
+            '--scale-hist-obs', '-b',
+            type=click.Choice(['linear', 'log', 'symlog', 'logit']),
+            default='log',
+            show_default=True,
+            help='Set y axis scale transformation in matplotlib for the plot of observed transcriptomes.'
+        ),
+         click.option(
+            '--scale-hist-sim', '-s',
+            type=click.Choice(['linear', 'log', 'symlog', 'logit']),
+            default='linear',
+            show_default=True,
+            help='Set y axis scale transformation in matplotlib for the plot of observed transcriptomes.'
+        ),
+     ],
+
+    'scrublet_simulate_doublets': [
+        *COMMON_OPTIONS['input'],
+        *COMMON_OPTIONS['output'],
+        *COMMON_OPTIONS['scrublet'],
+        click.option(
+            '--layer', '-l',
+            type=click.STRING,
+            default=None,
+            help="Layer of adata where raw values are stored, or ‘X’ if values "
+            "are in .X."
+        ),
+    ],
 
     'embed': [
         *COMMON_OPTIONS['input'],
@@ -1803,10 +2007,10 @@ CMD_OPTIONS = {
         ),
         click.option(
             '--color',
-            type=click.STRING,
+            type=CommaSeparatedText(simplify=True),
             default=None,
             show_default=True,
-            help='Key for annotation of observations/cells or variables/genes.',
+            help='Key(s) for annotation of observations/cells or variables/genes. Comma-separated if more than one',
         ),
         click.option(
             '--legend-loc',
